#!/bin/bash
#
# source : http://libopenraw.freedesktop.org/download/libopenraw-0.0.9.tar.bz2
#
# maintainer: gmg (g.monpontet@gmail.com)
#

soft='libopenraw'
softversion='0.0.9'
packageversion='72.1'

arch='i486'
cpu='i686'

buildir=$(pwd)
srcpkg="$buildir/$soft-$softversion.tar.bz2"
src="$buildir/$soft-$softversion"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"

cd $buildir
rm -rf $src
tar -xvf $srcpkg
rm -f $dest.txz
rm -rf $dest

cd $src
chown -R root:root .
find . \
 \( -perm 777 -o -perm 775 -o -perm 711 -o -perm 555 -o -perm 511 \) \
 -exec chmod 755 {} \; -o \
 \( -perm 666 -o -perm 664 -o -perm 600 -o -perm 444 -o -perm 440 -o -perm 400 \) \
 -exec chmod 644 {} \;
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"
./configure \
  --prefix=/usr \
  --disable-static

make -j5
make install DESTDIR=$dest

find $dest | xargs file | grep -e "executable" -e "shared object" | grep ELF \
  | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

# Documentation

mkdir -p $dest/usr/doc/$soft-$softversion
cp -a AUTHORS ChangeLog COPYING NEWS README TODO $dest/usr/doc/$soft-$softversion

# Description file
mkdir -p $dest/install
cat << EODESC >> $dest/install/slack-desc
# HOW TO EDIT THIS FILE:
# The "handy ruler" below makes it easier to edit a package description.  Line
# up the first '|' above the ':' following the base package name, and the '|' on
# the right side marks the last column you can put a character in.  You must make
# exactly 11 lines for the formatting to be correct.  It's also customary to
# leave one space after the ':'.

          |-----handy-ruler--------------------------------------------------|
libopenraw: Libopenraw (provide implementation for camera RAW files decoding)
libopenraw:
libopenraw: libopenraw is an ongoing project to provide a free software 
libopenraw: implementation for camera RAW files decoding. One of the main
libopenraw: reason is that dcraw is not suited for easy integration into 
libopenraw: applications, and there is a need for an easy to use API to build
libopenraw: free software digital image processing application.
libopenraw:
libopenraw:
libopenraw:
libopenraw:
EODESC

cat << DOINST > $dest/install/doinst.sh
#!/bin/sh
 if [ -x /usr/bin/gdk-pixbuf-query-loaders ]; then
 /usr/bin/gdk-pixbuf-query-loaders --update-cache >/dev/null 2>&1
fi
DOINST

mkdir -p $dest/usr/src/$soft-$softversion
cp $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion

# Packaging
cd $dest
makepkg -l y -c n $dest.txz

cd $buildir
md5sum $package.txz > $package.md5